Variable | django_redux API Document

# Variable

Static Public Summary
public | reduxBridge: ReduxSocketBridge Convenience singleton for `ReduxSocketBridge`. |
public | webSocketBridge: WebSocketBridge Convenience singleton for `WebSocketBridge`. |

## Static Public

### public reduxBridge: ReduxSocketBridge source

    import {reduxBridge} from 'django_redux/lib/index'

Convenience singleton for `ReduxSocketBridge`.

#### Example:

    import { ReduxBridge } from 'django_redux';

    ReduxBridge.connect();
    ReduxBridge.listen(store);

### public webSocketBridge: WebSocketBridge source

    import {webSocketBridge} from 'django_redux/lib/index'

Convenience singleton for `WebSocketBridge`.

#### Example:

    import { webSocketBridge } from 'django_redux';

    webSocketBridge.connect();
    webSocketBridge.listen(function(action, stream) { console.log(action) });